
define openssl(version) {
    file["/etc/openssl"] {
        source => "http:...$version"
    }

    package[openssl] {
        version => $version
    }
}

define cfengine(version) {
    package[cfengine] {
        version => $version
    }
    file["/usr/local/sbin/cf*"] {
        link => "/var/cfengine/bin"
    }

    # XXX seems like these should be more closely related
    file["/var/cfengine/ppkeys/localhost.pub"] {
        exist => true,
        action => warn
    }

    # run this if the cfengine key is missing
    exec["cfkey"] {
        path => "/usr/local/sbin:/usr/sbin:/sbin",
        require => file["/var/cfengine/ppkeys/localhost.pub"]
    }

    service[cfengine] {
        running => true,
        enabled => true
    }
}

define mysql(version,uid,gid) {
    group["mysql"] {
        gid => $gid
    }
    user["mysql"] {
        uid => $uid
    }
    package["mysql"] {
        version => $version
    }
}

define dhcp(version) {
    package[dhcp] {
        version => $version
    }
    file["/etc/dhcpd"] {
        source => "http:..."
    }
}

class sunsshupgrade {
    package[openssh] {
        version => "3.6.1p2"
    }

    service[prngd] {
        enabled => false,
        running => false
    }
}

class cfenginesetup {
    cfengine {
        version => "2.0.4"
    }
}

class web_log_db {
    mysql {
        version => "4.0.14",
        gid => 80,
        uid => 80
    }
}

class san_attached_jni {
    package[sansupport] { version => "1.0" }
    patch["sanpatches_200307"] { backup => false, schedule => boot }
    
    # no way to model rootdg stuff
	# rootdg-detach

    file[/opt/JNIsni] { create => directory }
    file { create => directory }
    file { /opt/JNIsni: create => directory }
    file { /opt/JNIsni create => directory }

    package { jnic: version="1.0" }
}

class dhcp_server inherits sun_server {
    dhcp {
        version => "3.0"
    }
}

class sun_boot_server inherits sun_server {
    nfsshare["jump"] {
        fs => "/jumpstart",
        mode => "ro"
    }
}

class msync_server inherits sun_server {
    file["/etc/rsync"] {
        create => directory
    }

    service { rsyncd
        enabled => 80
    }
    service[rsyncd] {
        enabled => 80
    }


}

msync_server: sun_server
	known_hosts_cron
	rsync/mk_rsynconfigdir
	rsync/fileset__depotroot__isconf--filesets--depot
	rsync/fileset__pkgroot__isconf--filesets--pkg
	rsync/fileset__tarroot__isconf--filesets--tar
	rsync/fileset__perlroot__isconf--filesets--perl5
	rsync/add__pkgroot
	rsync/add__tarroot
	rsync/add__perlroot
	filesets-tarroot
	filesets-pkgroot
	filesets-perlroot
	rsync/startup
	ln/..--init.d--rsyncd__etc--rc2.d
	/etc/rsyncd.conf
	hourly_cron
	mkdir/isconf--filesets--perlparseroot
	cp_perlparseroot
	rsync/fileset__perlparseroot__isconf--filesets--perlparseroot
	rsync/add__perlparseroot
	filesets-perlparseroot
	rsync/fileset__depot__isconf--filesets--depot
	rsync/add__depot
	rsync/fileset__pkg__isconf--filesets--pkg
	rsync/add__pkg
	rsync/fileset__filesets__isconf--filesets
	rsync/add__filesets
	rsync/fileset__tar__isconf--tar
	rsync/add__tar
	rsync/mkconfig__tar__isconf--filesets--tar
	rmdir/isconf--tar
	add-pkg-nfs
	rm/norecurse--etc__rc2.d__rsyncd
	ln/..--init.d--rsyncd__etc--rc2.d--S80rsyncd
	rmknown_hosts_cron
	installcopy/copy--openssl--0.9.6g
	installcopy/copy--db--3.3.11
	installcopy/copy--cfengine--2.0.4
	installcopy/cfenginelinks
	installcopy/cfengine-init
	filesets/rm__tarroot
	filesets/rm__pkgroot
	filesets/rm__perlroot
	filesets/add__filesetmroot
	filesets/rm__perlparseroot
	filesets/add__sunpatchroot
	add-patch-nfs


cvs_server: sun_server
	rsync/mk_rsynconfigdir
	rsync/fileset__cvsroot__cvsroot
	rsync/add__cvsroot
	filesets-cvsroot
	rsync/startup
	ln/..--init.d--rsyncd__etc--rc2.d
	/etc/rsyncd.conf
	mkdir/var--lock
	mkdir/var--lock--cvs
	groupadd/cvs__15
	add-cvs-user
	chown/var--lock--cvs__cvs__cvs
	chmod-cvslock
	tar/cvshome.tar.gz-opt_cvs
	filesets/add__genesiscvs
	add-genesis-group
	add-genesis-user
	installcopy/copy--openssl--0.9.6g
	installcopy/copy--db--3.3.11
	installcopy/copy--cfengine--2.0.4
	installcopy/cfenginelinks


rsync_server: sun_server
	rsync/fileset__code__isconf--code
	rsync/fileset__filesets__isconf--filesets
	rsync/add__code
	rsync/add__filesets
	filesets-coderoot
	filesets-filesetroot
	known_hosts_cron
	rsync/startup
	ln/..--init.d--rsyncd__etc--rc2.d
	/etc/rsyncd.conf
	rsync/fileset__isconf__isconf--code--isconf
	rsync/add__isconf
	filesets-isconfperl
	filesets-perlparser
	hourly_cron
	rm/norecurse--etc__rc2.d__rsyncd
	ln/..--init.d--rsyncd__etc--rc2.d--S80rsyncd
	rm-badlinks
	ln/etc--init.d--rsyncd__etc--rc2.d--S80rsyncd
	installcopy/copy--openssl--0.9.6g
	installcopy/copy--db--3.3.11
	installcopy/copy--cfengine--2.0.4
	installcopy/cfenginelinks


crm_web_server: sun_server
	ipws_4.1sp9
	siebel_accounts
	epiphany_accounts
	pkg/osadd__SUNWbtool
	pkg/osadd__SUNWctpls
	pkg/osadd__SUNWmfrun
	pkg/osadd__SUNWadmap
	patch-20020410 CONTEXT=BOOT


epiphany_cme_server: sun_server
	epiphany_accounts
	cme_accounts


epiphany_server: sun_server
	oraclient_8.1.7
	filesets/add__oraclient_8_1_7
	epiphany_accounts
	weblogic_service_user
	pkg/osadd__SUNWscpu
	java_1.3.0
	pkg/osadd__SUNWbtool
	pkg/osadd__SUNWctpls
	pkg/osadd__SUNWmfrun
	pkg/osadd__SUNWadmap

epiphany_rt_server: epiphany_server
	filesets/add__epirealtime_start
	ln/etc--init.d--epirealtime__etc--rc2.d--S902epirealtime
	ln/etc--init.d--epirealtime__etc--rc2.d--K902epirealtime

epiphany_analyze_server: epiphany_server
	filesets/add__epianalyze_start
	ln/etc--init.d--epianalyze__etc--rc2.d--S903epianalyze
	ln/etc--init.d--epianalyze__etc--rc2.d--K903epianalyze


siebel_server: sun_server
	oraclient_8.1.7
	filesets/add__oraclient_8_1_7
	siebel_accounts
	resonate_accounts
	pkg/osadd__SUNWbtool
	pkg/osadd__SUNWctpls
	pkg/osadd__SUNWmfrun
	pkg/osadd__SUNWadmap
	patch-20020410 CONTEXT=BOOT


siebel_gateway_server: sun_server
	siebel_accounts
	resonate_accounts
	pkg/osadd__SUNWbtool
	pkg/osadd__SUNWctpls
	pkg/osadd__SUNWmfrun
	pkg/osadd__SUNWadmap
	patch-20020410 CONTEXT=BOOT
	oraclient_8.1.7
	filesets/add__oraclient_8_1_7


dns_server: sun_server
	CATbind_8.3.3


cognos_server: sun_server
	cognos_service_user
	pkg/add__java__1.4.1


weblogic_61sp4: weblogic_server
	tar/weblogic_6.1sp4.tar.gz-opt_bea

weblogic_server: sun_server
	weblogic_service_user
	pkg/add__weblogic__6.1sp2
	pkg/osadd__SUNWscpu
	java_1.3.0
	filesystems/new--c0t0d0s5--7g--var__ebusiness CONTEXT=BOOT
	oraclient_8.1.7
	filesets/add__oraclient_8_1_7
	pkg/osadd__SUNWbtool
	pkg/osadd__SUNWctpls
	pkg/osadd__SUNWmfrun
	pkg/osadd__SUNWadmap
	add-logical-interface


fcc_fe1:
	add-weblogic3-cron
	rm-weblogic3-cron


fcc_fe2:
	add-weblogic1-cron
	add-weblogic2-cron
	tar/java1.3.1.6.tar.gz-usr_java1.3.1.6
	add-weblogic4-cron
	rm-weblogic1-cron
	rm-weblogic4-cron
	add-weblogic5-cron

iplanet_web_server: sun_server
	ipws_6.0sp2


sce_server: sun_server iplanet_web_server
	tar/ipws60sp4.tar-tmp_ipws
	tar/java1.3.1.6.tar.gz-usr_java1.3.1.6
	oraclient_8.1.7
	filesets/add__oraclient_8_1_7
	pkg/osadd__SUNWbtool
	pkg/osadd__SUNWctpls
	pkg/osadd__SUNWmfrun
	pkg/osadd__SUNWadmap
	pkg/osadd__SUNWscpu

dmz_server: sun_server iplanet_web_server
	tar/ipws60sp4.tar-tmp_ipws

jumpstart_server: sun_server
	rsync/mkconfig__jumproot__isconf--jump
	rsync/add__jumproot
	filesets/add__jumproot
	tftp_service
	add-jump-nfs
	mkdir/tftpboot


crossworlds_server: sun_server
	mqs_service
	pkg/osadd__SUNWceuow
	pkg/osadd__SUNWeeuos
	pkg/osadd__SUNWneuos
	pkg/osadd__SUNWseuow
	pkg/osadd__SUNWuium
	pkg/osadd__SUNWulcf
	pkg/osadd__SUNWweuos
	pkg/osadd__SUNWweuow
	pkg/osadd__SUNWweuow


fpd_crossworlds_server:
	pkg/osadd__SUNWceuow
	pkg/osadd__SUNWeeuos
	pkg/osadd__SUNWneuos
	pkg/osadd__SUNWseuow
	pkg/osadd__SUNWuium
	pkg/osadd__SUNWulcf
	pkg/osadd__SUNWweuos
	pkg/osadd__SUNWweuow
	pkg/osadd__SUNWweuow
	mqs_service


pivot_server: sun_server
	oraclient_8.1.7
	filesets/add__oraclient_8_1_7


rms_wren_tomcat: sun_server weblogic_server
	add-rms-uat-cron
	del-rms-uat-cron


rms_perch_lion: sun_server weblogic_server
	add-rms-prod-cron
	del-rms-prod-cron


legacy_oraclients:
	filesets/add__oraclient_8_1_7

legacy_oraclients_9_0_1:
	filesets/add__oraclient_9_0_1

bind_9_slave:
	tar/bind_9.2.2.tar.gz-opt
	mkdir/var--named
	filesets/add__bind_9
	filesets/add__varnamed
	ln/etc--init.d--bind9__etc--rc2.d--S89named
	ln/opt--bind-9.2.2__opt--bind
	filesets/add__slave_dns

postfix_mailhub:
	pkg/add__postfix__2.07
	postfix_account
	filesets/add__posthub
	filesets/add__postfix

filenet_server: sun_server
	pkg/osadd__SUNWarc
	pkg/osadd__SUNWbtool
	oraclient_8.1.7
	filesets/add__oraclient_8_1_7
	pkg/osadd__SUNWbcp
	pkg/osadd__SUNWscpu
	pkg/osadd__SUNWctpls
	pkg/osadd__SUNWmfrun
	pkg/osadd__SUNWadmap
	java_1.3.0
	filenet_account
	mkdir/opt--filenet
	chown/opt--filenet__edmsadm__imagadm

bind_9_master:
	tar/bind_9.2.2.tar.gz-opt
	mkdir/var--named
	filesets/add__varnamed
	ln/etc--init.d--bind9__etc--rc2.d--S89named
	ln/opt--bind-9.2.2__opt--bind

crm_devel:
	pkg/add__gcc__3.3
	pkg/osadd__SUNWarc
	pkg/osadd__SUNWarcx


main_cfserver:
	filesets/add__cfengine_root

dboxes:
	dbox-nocfengine
	nashimag-cleanup
	dbox-nocfengine2

oracle_crm_server:
	epiphany_accounts
	filesystems/importvg__vgcrm-prod-u17__0x020000
	filesystems/importvg__vgcrm-prod-u19__0x030000
	filesystems/importvg__vgora_gen__0x040000
	filesystems/importvg__vgora_util__0x050000
	filesystems/addmount__vgcrm-prod-u17__u17__u17
	filesystems/addmount__vgcrm-prod-u19__u19__u19
	filesystems/addmount__vgora_gen__u02__u02
	filesystems/addmount__vgora_gen__u03__u03
	filesystems/addmount__vgora_gen__u04__u04
	filesystems/addmount__vgora_util__u18__u18
	filesystems/mount__u17
	filesystems/mount__u19
	filesystems/mount__u02
	filesystems/mount__u03
	filesystems/mount__u04
	filesystems/mount__u18
	filesets/add__epichannel_start
	ln/sbin--init.d--epichannel__sbin--rc2.d--S901epichannel
	ln/sbin--init.d--epichannel__sbin--rc2.d--K901epichannel

oracle_cluster_1: vcs_cluster oracle_server
	CLUSTER_MEMBERS="mullet mackerel"
	CLUSTERID=1
	pkg/VRTSoracle--2.0--Veritas
	lanconfig/enable--lan1--${IP1}--255.255.255.0
	installcopy/copy--openssl--0.9.6g
	installcopy/copy--db--3.3.11
	installcopy/copy--cfengine--2.0.4
	installcopy/cfenginelinks
	filesets/add__oracle
	filesets/add__oracle-server
	filesets/add__cluster-control-oracle
	filesets/add__cluster-oracle1
	filesystems/importvg__vgora-twp1__0x010000
	filesystems/importvg__vgora-catusedp__0x020000
	filesystems/importvg__vggab__0x030000
	tar/oracle_8.1.7.1.tgz-u01_app_oracle_product_8.1.7
	oracle-kernel-params_1.0 CONTEXT=BOOT
	mkdir/u02--oradata--twp1
	mkdir/u03--oradata--twp1
	mkdir/u04--oradata--twp1
	mkdir/u05--oradata--arch--twp1
	mkdir/u08--oradata--twp1
	mkdir/u01--app--oracle--product--8.1.7--admin--twp1
	mkdir/u02--oradata--catusedp
	mkdir/u03--oradata--catusedp
	mkdir/u04--oradata--catusedp
	mkdir/u05--oradata--arch--catusedp
	mkdir/u07--oradata--catusedp
	mkdir/u01--app--oracle--product--8.1.7--admin--catusedp

oracle_cluster_2: hpux_11i_server hp_fc_server
	CLUSTER_MEMBERS="parrot finch"
	CLUSTERID=2
	installcopy/copy--openssl--0.9.6g
	installcopy/copy--db--3.3.11
	installcopy/copy--cfengine--2.0.4
	installcopy/cfenginelinks
	filesets/add__netbackup

vcs_cluster:
	pkg/vxlicence--3.00.007e--Veritas
	pkg/VCS--3.5--Veritas
	vcs/configure

sg_cluster:
	mc-serviceguard CONTEXT=BOOT
	inetd/install__hacl

test_oracle: hpux_11i_server hp_fc_server
	filesystems/new__boot__u01__3000__u01
	oracle-patches-200209 CONTEXT=BOOT
	oracle_user
	pkg/add__oraserver__8.1.7.3

rsa_server:  hpux_11_0_server
	mkfs_2048-rsa-boot
	newfs_rsa-boot
	mountfs_rsa-boot-rsa
	addrsa_services
	fixrsa_services1
	fixrsa_services2

oracle_server: hpux_11i_server hp_fc_server
	filesystems/new__boot__u01__3000__u01
	oracle-patches-200209 CONTEXT=BOOT
	oracle_user
	cron/allow__oracle
	filesets/add__netbackup

oracle_quorum: hpux_11i_server hp_fc_server
	oracle-patches-200209 CONTEXT=BOOT
	oracle_user


ilease_bkup: infolease_server

infolease_server: hpux_11i_server
	mkfs-ud40
	fs_patches
	tar/SB.tar.gz-opt_SB
	add_menu
	tar/peek.tar-opt_peek
	tar/fpd-scripts.tar.gz-opt_fpd_scripts
	tar/pksh.tar-usr_bin
	ln/usr--bin--pksh__usr--bin--pksh-cfsh
	ln/usr--bin--pksh__usr--bin--pksh-csh
	ln/usr--bin--pksh__usr--bin--pksh-ksh
	ln/usr--bin--pksh__usr--bin--pksh-sh 
	tar/pivot.tar.gz-opt_pivot
	tar/Pivot3.tar.gz-opt_Pivot3
	tar/ndm.tar.gz-opt_ndm
	tar/u01.tar.gz-opt_oracle
	ln/u01__opt--oracle
	mkdir/var--opt--fpd
	tar/cron.allow.tar-var_adm_cron
	P3DHCASU_cron
	mkdir/var--opt--rr
	tar/rr.tar.gz-opt_rr
	MUX-B.11.11.05 CONTEXT=BOOT
	tar/rdoc_tc.tar.gz-opt_rdoc-tc
	mkdir/var--opt--rdoc_tc
	tar/passwdunix.tar.gz-usr_bin
	mkdir/opt--cleo
	pkg/Java--1.2.2--HP
	statd_service
	mkdir/etc--opt--rdoc_tc
	tar/optsdi.tar.gz-opt_sdi
	tar/crontabs.tar-var_spool_cron_crontabs
	tar/compx.tar.gz-opt_compx
	mkdir/var--opt--menu
	mkdir/var--opt--menu--adm
	mkdir/var--opt--menu--adm--sudocheck
	pci-mux CONTEXT=BOOT
	pkg/Java--1.3.1--HP
	ln/sbin--init.d--cdunix__sbin--rc2.d--K010cdunix
	ln/sbin--init.d--ud40__sbin--rc2.d--K100ud40
	ln/sbin--init.d--cdunix__sbin--rc3.d--S990cdunix
	ln/sbin--init.d--ud40__sbin--rc3.d--S900ud40
	unidata_service
	horcm_services
	ln/HORCM--usr--bin--paircreate__usr--bin--paircreate
	ln/HORCM--usr--bin--paircurchk__usr--bin--paircurchk
	ln/HORCM--usr--bin--pairdisplay__usr--bin--pairdisplay
	ln/HORCM--usr--bin--pairevtwait__usr--bin--pairevtwait
	ln/HORCM--usr--bin--pairmon__usr--bin--pairmon
	ln/HORCM--usr--bin--pairresync__usr--bin--pairresync
	ln/HORCM--usr--bin--pairsplit__usr--bin--pairsplit
	ln/HORCM--usr--bin--pairsyncwait__usr--bin--pairsyncwait
	ln/HORCM--usr--bin--pairvolchk__usr--bin--pairvolchk
	ln/HORCM--usr--bin--raidar__usr--bin--raidar
	ln/HORCM--usr--bin--raidqry__usr--bin--raidqry
	ln/HORCM--usr--bin--raidscan__usr--bin--raidscan
	ln/HORCM--usr--bin--horcctl__usr--bin--horcctl
	ln/HORCM--usr--bin--horcmshutdown.sh__usr--bin--horcmshutdown.sh
	ln/HORCM--usr--bin--horcmstart.sh__usr--bin--horcmstart.sh
	ln/HORCM--usr--bin--horctakeover__usr--bin--horctakeover
	ln/HORCM--etc--horcmgr__etc--horcmgr
	inetd/del__rlogin
	mkdir/tmp--monitor
	fast_service
	modunidata_services


netbackup_server: hpux_11i_server
	netbackup-gige CONTEXT=BOOT
	netbackup-disable-100m CONTEXT=BOOT

netbackup_media_server: hpux_11i_server
	netbackup_server_service
	pkg/nbmedia--3.4.1_3--CFSC
	pkg/rmtapedevs--1.0--CFSC

netbackup_name_change: hpux_11i_server
	newlv_13890-netbackup-vgveritas
	newfs_13890-netbackup-vgveritas
	mountfs_netbackup-vgveritas-opt_openv
	fs_patches
	netbackup_server_service
	pkg/rmtapedevs--1.0--CFSC

hp_fc_server: 
	fibrechannel CONTEXT=BOOT 
	fs_patches CONTEXT=BOOT

hp_web_server: hpux_11_0_server hp_fc_server 
	hotspot-patch CONTEXT=BOOT 

depot_server: hpux_11i_server
	setup-depots
	filesystems/isconf
	nfsserver
	rsync/mkconfig__depot__isconf--filesets--depot
	rsync/add__depot
	rsync/mkconfig__depotroot__isconf--filesets--depot
	rsync/add__depotroot
	filesets/add__depotroot
	rsync/mkconfig__sdroot__var--depot
	rsync/add__sdroot
	filesets/add__sdroot
	chmoddepot
	depotexports
	rsync/mkconfig__filesets__isconf--filesets
	rsync/add__filesets
	installcopy/copy--openssl--0.9.6g
	installcopy/copy--db--3.3.11
	installcopy/copy--cfengine--2.0.4
	installcopy/cfenginelinks
	filesets/rm__depotroot
	filesets/add__filesetdroot

ignite_server: hpux_11i_server
	Ignite-UX-B.3.7.96
	filesets-ignite
	enable_nfs
	tftp_service
	ignite_tftp_service
	instl_bootd_service
	inetd/add__instl_bootd
	filesets/rm__ignite
	ignitenfsexports
	nfsserver
	rsync/mkconfig__varignite__var--opt--ignite
	rsync/add__varignite
	filesets/add__varignite
	installcopy/copy--openssl--0.9.6g
	installcopy/copy--db--3.3.11
	installcopy/copy--cfengine--2.0.4
	installcopy/cfenginelinks

ldap_server: hpux_11_0_server
	iplanet-ldap-5.0 

ldap_client:
	native-ldap CONTEXT=BOOT

hp_11i_compiler:
	pkg/B3901BA--B.11.11.04--HP

hp_11i_buildhost: hp_11i_compiler
	filesets-buildhost
	buildhost-links
	hp-enable-automount
	pkg/binutils__2.13__CFSC
	pkg/diffutils__2.8__CFSC
	pkg/fileutils__4.1__CFSC
	pkg/findutils__4.1__CFSC
	pkg/gcc__3.1__CFSC
	pkg/lndir__1.14__CFSC
	pkg/shutils__2.0__CFSC
	pkg/tar__1.13__CFSC
	pkg/textutils__2.1__CFSC
	pkg/vim__6.1__CFSC
	pkg/gdbm__1.8.3__CFSC
	pkg/openssl__0.9.6g__CFSC
	pkg/openldap__2.1.8__CFSC
	installcopy/copy--openssl--0.9.6g
	installcopy/copy--db--3.3.11
	installcopy/copy--cfengine--2.0.4
	installcopy/cfenginelinks
	installcopy/cfengine-init

hp_110_buildhost: hp_11i_compiler
	filesets-buildhost
	buildhost-links
	hp-enable-automount
	pkg/binutils__2.13__CFSC
	pkg/diffutils__2.8__CFSC
	pkg/fileutils__4.1__CFSC
	pkg/findutils__4.1__CFSC
	pkg/gcc__3.1__CFSC
	pkg/lndir__1.14__CFSC
	pkg/shutils__2.0__CFSC
	pkg/tar__1.13__CFSC
	pkg/textutils__2.1__CFSC
	pkg/vim__6.1__CFSC
	pkg/gdbm__1.8.3__CFSC
	pkg/openssl__0.9.6g__CFSC
	pkg/openldap__2.1.8__CFSC
	installcopy/copy--openssl--0.9.6g
	installcopy/copy--db--3.3.11
	installcopy/copy--cfengine--2.0.4
	installcopy/cfenginelinks
	installcopy/cfengine-init

sun_srchost: sun_server
	installcopy/copy--openssl--0.9.6g
	installcopy/copy--db--3.3.11
	installcopy/copy--cfengine--2.0.4
	installcopy/cfenginelinks
	installcopy/cfengine-init

sun_buildhost: sun_opensrc_tools
	filesets-buildhost
	buildhost-links
	pkg/osadd__SUNWlibm
	pkg/osadd__SUNWbtool
	pkg/osadd__SUNWarc
	pkg/osadd__SUNWarcx
	pkg/add__binutils__2.13
	pkg/add__gcc__3.1
	pkg/add__lndir__1.44
	pkg/add__gdbm__1.8.3
	pkg/add__openssl__0.9.6g
	pkg/add__openldap__2.1.8
	installcopy/copy--openssl--0.9.6g
	installcopy/copy--db--3.3.11
	installcopy/copy--cfengine--2.0.4
	installcopy/cfenginelinks
	installcopy/cfengine-init

sun_opensrc_tools:
	pkg/add__diffutils__2.8
	pkg/add__fileutils__4.1
	pkg/add__findutils__4.1
	pkg/add__shutils__2.0
	pkg/add__tar__1.13
	pkg/add__textutils__2.1
	pkg/add__vim__6.1

mailhub: 
	filesets-mailhub

logreporter:
	allow_adm_cron
	sudoreport_cron

mainloghost: 
	pkg/add__syslogng__1.5.19
	filesets-loghost
	filesystems/new--c0t0d0s5--free--var__adm__log
	rm/norecurse--etc__rc2.d__S74syslog
	ln/..--init.d--syslog-ng__etc--rc2.d--S74syslog-ng
	rm-badlinks
	ln/etc--init.d--syslog-ng__etc--rc2.d--S74syslog-ng
	mysql-ng
	installcopy/copy--openssl--0.9.6g
	installcopy/copy--db--3.3.11
	installcopy/copy--cfengine--2.0.4
	installcopy/cfenginelinks

openview_server: hp_fc_server
	dce-kt-tools CONTEXT=BOOT 
	qpk-B.11.00.56.5 CONTEXT=BOOT 
	openview_patches CONTEXT=BOOT 


sun_workstation: sun_standard_inetd_services cfengine_setup
	INETD_FLAGS='-s -t'
	filesets-common 
	filesets-IS_OS 
	filesets-IS_DOMAIN 
	daily_cron
	rsync_all 
	install
	filesets-workstation_dns
	set-acct-crons
	fpd-fileset-fix
	aliases-backup
	rm-acct-crons
	90day-passwd
	etc-hosts-cron
	rm-etc-hosts-cron
	etc-hosts-cron2
	installcopy/cfenginelinks
	installcopy/cfengine-init
	cfinit
	pkg/add__pentasafe__3.22
	pentasafe_service
	tar/pentasafe.SunOS.tar.gz-opt_pentasafe_SunOS 
	set-root-GCOS 
	man-cleanup-XcmsSetCCCOfColormap

sun_workstation_no_nfs: sun_server localbase
	INETD_FLAGS='-s -t'
	filesets-common
	filesets-IS_OS
	filesets-IS_DOMAIN
	daily_cron
	rsync_all
	install
	filesets-workstation_dns
	set-acct-crons
	fpd-fileset-fix
	aliases-backup
	rm-acct-crons
	90day-passwd
	etc-hosts-cron
	rm-etc-hosts-cron
	etc-hosts-cron2
	installcopy/cfenginelinks
	installcopy/cfengine-init
	cfinit
	pkg/add__pentasafe__3.22
	pentasafe_service
	tar/pentasafe.SunOS.tar.gz-opt_pentasafe_SunOS
	set-root-GCOS
	man-cleanup-XcmsSetCCCOfColormap

sun_server: sunos_base localbase
	cvs_1.11 
	openssh_2.9.2 
	sudo_1.6.3p5 
	install-disksuite CONTEXT=BOOT 
	fix-auto_master
	install_ovo
	fix-opc-group
	fix-opc-acct
	rechown-opc
	pkg/add__top__3.5beta9
	pkg/add__nbclient__3.4.1.3
	netbackup_service
	pkg/add__pentasafe__3.22
	pentasafe_service
	tar/pentasafe.SunOS.tar.gz-opt_pentasafe_SunOS

hpux_11i_server: hpux_base osbase localbase hpux_server_base
	onlinejfs3.3 CONTEXT=BOOT
	OnlineDiag-B.11.11.07.11 CONTEXT=BOOT
	GOLDBASE11i-B.11.11.0206.4 CONTEXT=BOOT
	GOLDAPPS11i-B.11.11.0206.4 CONTEXT=BOOT
	glance
	pkg/VigilEnt--3.22--Pentasafe
	pentasafe_service

hpux_11_0_server: hpux_base osbase localbase hpux_server_base
	dce-core-tools CONTEXT=BOOT 
	dce-kt-tools CONTEXT=BOOT 
	unlimited-user CONTEXT=BOOT 
	qpk-B.11.00.56.5 CONTEXT=BOOT 
	predictive 
	OnlineDiag-B.11.00.21.10 CONTEXT=BOOT
	pkg/VigilEnt--3.22--Pentasafe
	pentasafe_service

hpux_ISEE_testtype:
	pkg/ISEE--A.03.00.024--HP

hpux_server_base: 
	cvs1.11.1.p1 
	bash2.05 
	openssh2.9p2 
	less358
	hp_mirror CONTEXT=BOOT 
	gzip1.2.4a 
	sudo1.6.3b7 
	ovo_install
	pkg/nbclient--3.4.1_3--CFSC
	standard_service
	netbackup_service
	telnet_service
	ftp_service
	statd_service
	pkg/textutils__2.1__CFSC
	pkg/vim__6.1__CFSC
	pkg/shutils__2.0__CFSC
	tar/hp__sysinfo.tar.gz-usr_local_bin
	tar/securetty.tar.gz-etc
	ln/sbin--init.d--onlinejfs__sbin--rc1.d--S090onlinejfs

sunos_base: osbase  sun_standard_inetd_services sun_opensrc_tools
	INETD_FLAGS='-s -t'
	set-fslogging CONTEXT=BOOT 
	jass-server-base-harden1.0 CONTEXT=BOOT 
	set-acct-crons
	pkg/add__make__3.79.1
	pkg/add__lsof__4.49
	pkg/add__rdist__6.1.5
	rm-acct-crons
	90day-passwd
	pkg/add__shutils__2.0
	pkg/add__textutils__2.1
	pkg/add__vim__6.1
	refresh-cfengine
	man-cleanup-XcmsSetCCCOfColormap

hpux_base: osbase
	pkg/make--3.79.1--CFSC
	makelink
	enable-trusted-system 
	fix-install-perms 
	dmesg-cron
	startup-trim CONTEXT=BOOT
	init_nfsconf
	pkg/lsof__4.64__CFSC
	pkg/rdist__6.1.5__CFSC
	pkg/libpcap__0.6.2__CFSC
	pkg/tcpdump__3.7.1__CFSC
	90day-password
	5passwd-tries
	nologin-sshd

osbase: cfengine_setup
	IS_INETD_SVCS='telnet ftp'
	filesets-common 
	filesets-IS_OS 
	filesets-IS_DOMAIN 
	rsync_all 
	change-root-home CONTEXT=BOOT 
	set-root-GCOS 
	install
	daily_cron
	uselogin-sshd
	cron/allow__adm
	rm-cricket-mkdiskcfg
	rm-cricket-fsinfo
	add-cricket-mkdiskcfg
	add-cricket-fsinfo
	installcopy/copy--openssl--0.9.6g
	installcopy/copy--db--3.3.11
	installcopy/copy--cfengine--2.0.4
	installcopy/cfenginelinks
	installcopy/cfengine-init
	setdomain

localbase: 
	filesets-local-scripts 
	filesets-all-perl
	filesets-local-perl 
	filesets-known_hosts
	filesets-sudo

sun_standard_inetd_services:
	telnet_service
	ftp_service
	rstatd_service
	printer_service
	standard_service

fpd_sun: fpd_servers
	pkg/add__make__3.79.1
	pkg/add__lsof__4.49
	90day-passwd
	pkg/add__nbclient__3.4.1.3

fpd_hp: fpd_servers
	pkg/make--3.79.1--CFSC
	pkg/lsof__4.64__CFSC
	pkg/libpcap__0.6.2__CFSC
	pkg/tcpdump__3.7.1__CFSC
	pkg/rdist__6.1.5__CFSC
	5passwd-tries
	nologin-sshd
	tar/securetty.tar.gz-etc

fpd_servers:  fpd_cfengine_setup
	INETD_FLAGS='-s -t'
	filesets-common 
	filesets-IS_OS 
	filesets-IS_DOMAIN 
	filesets-all-perl 
	filesets-local-perl 
	filesets-local-scripts 
	filesets-known_hosts
	filesets-sudo
	daily_cron
	rm_cvsdirs_cron
	rsync_all 
	install
	fpd-fileset-fix
	aliases-backup
	uselogin-sshd
	cron/allow__adm
	rm-cricket-mkdiskcfg
	rm-cricket-fsinfo
	add-cricket-mkdiskcfg
	add-cricket-fsinfo

fpd_workstations: sun_standard_inetd_services cfengine_setup
	INETD_FLAGS='-s -t'
	filesets-common 
	filesets-IS_OS 
	filesets-IS_DOMAIN 
	daily_cron
	nsswitch-ldap
	rsync_all 
	install
	filesets-workstation_dns
	set-acct-crons
	fpd-fileset-fix
	aliases-backup
	rm-acct-crons
	90day-passwd
	etc-hosts-cron
	rm-etc-hosts-cron
	etc-hosts-cron2
	installcopy/cfenginelinks
	installcopy/cfengine-init
	cfinit
	pkg/add__pentasafe__3.22
	pentasafe_service
	man-cleanup-XcmsSetCCCOfColormap

fpd_fe_servers: fpd_servers
	filesets-fpd_fe

fpd_webserver: fpd_hp
	genesis-cvs-config
	installcopy/copy--vncserver--3.3.3r2
	vncserver-install-3.3.3r2
